* This do file creates the numbers in Table 1 of the paper showing summary statistics


clear

set mem 200m

set matsize 2000

use parseddata.dta

gsort fixedname - numcitations

by fixedname: gen npaper=sum(1/(numauthors))

by fixedname: gen npaperfull=sum(1)

gen h110 = min(numcitations,npaperfull)

gen h111 = min(numcitations,npaper)

gen h1521 = min((numcitations/15)^(1/2),npaper)

gen h9031 = min((numcitations/90)^(1/3),npaper)

gen totalcitesfull = numcitations

gen totalcites = numcitations/numauthors

gen byte papercount100 = numcitations >=100

replace papercount100 = papercount100/numauthors

gen byte papercount10 = numcitations >=10

replace papercount10 = papercount10/numauthors

collapse (count) numcitations (mean) numauthors (sum) totalcitesfull totalcites (max) h110 h111 h1521 h9031  (sum) papercount10 papercount100 , by(fixedname) 

rename numcitations numpapers

replace h110 = max(h110,1)

replace h111 = max(h111,1)

replace h1521 = max(h1521, (1/15)^(1/2))

replace h9031 = max(h9031, (1/90)^(1/3))

merge fixedname using facultylist.dta, unique sort _merge(_merge2)
keep if _merge2==3
drop _merge2

gen pos=.
replace pos=1 if position=="Assistant Professor"
replace pos=2 if position=="Associate Professor"
replace pos=3 if position=="Professor"

gen Tyear=2012-phdyear

preserve

keep if tenure=="Yes" & phdyear>=1987 & phdyear<=2004

sum Tyear numpapers numauthors totalcitesfull totalcites h110 h111 h1521 h9031 papercount10 papercount100

restore

**drop associate professors graduated before 1987
drop if Tyear>25 & pos==2 

sum Tyear numpapers numauthors totalcitesfull totalcites h110 h111 h1521 h9031 papercount10 papercount100


/* Here are the stata output from running this do file:



. sum Tyear numpapers numauthors totalcitesfull totalcites h110 h111 h1521 h9031 papercount10 papercount100

    Variable |       Obs        Mean    Std. Dev.       Min        Max
-------------+--------------------------------------------------------
       Tyear |       513    16.67251    5.166936          8         25
   numpapers |       513    71.95906    25.25882          8        100
  numauthors |       513    2.181847    .3232304   1.162791   3.104167
totalcites~l |       513    3247.437    4802.784         40      52343
  totalcites |       513    1792.887    2603.099       20.5   28550.83
-------------+--------------------------------------------------------
        h110 |       513    20.64133    11.72804          3         79
        h111 |       513    13.99796    7.955569          2   54.28333
       h1521 |       513    2.720686    1.026441   .8944272        7.5
       h9031 |       513    1.262268    .3610419   .5378096          3
papercount10 |       513     17.0526    12.52737          1      59.95
-------------+--------------------------------------------------------
papercou~100 |       513    4.149578    5.290859          0      41.45




. sum Tyear numpapers numauthors totalcitesfull totalcites h110 h111 h1521 h9031 papercount10 papercount100

    Variable |       Obs        Mean    Std. Dev.       Min        Max
-------------+--------------------------------------------------------
       Tyear |      1486    21.50875    13.89367          1         62
   numpapers |      1486    66.74832    33.44589          1        100
  numauthors |      1486    2.077169    .3927929          1   3.564103
totalcites~l |      1486    4549.989    8698.942          0     120561
  totalcites |      1486    2683.849    5398.777          0   60420.08
-------------+--------------------------------------------------------
        h110 |      1486    22.03567    18.01158          1        100
        h111 |      1486    15.59612    12.93267          1   85.91666
       h1521 |      1486    2.636605      1.5085   .2581989   9.811558
       h9031 |      1486    1.214611    .5302737   .2231443        3.5
papercount10 |      1486    20.32353     19.3974          0   85.91667
-------------+--------------------------------------------------------
papercou~100 |      1486    5.719818    9.639288          0   85.91667

*/






