**specify H-index ********************

local hcode "133" 
/* The hindex with a = 15, b = 2, c = 1 is in the 133rd column in index.csv*/
/* The hindex with a = 10, b = 3, c = 0.25 is in the 114th column in index.csv*/
/* The hindex with a = 30, b = 1, c = 1 is in the 197th column in index.csv*/
/* The hindex with a = 40, b = 1, c = 0 is in the 241st column in index.csv*/
local hparaname "15_2_1"


****do file title*************
****do file description*******

clear
set mem 200m
set matsize 3000
local DATE "Dec14"
log using "`DATE'_`hparaname'_NLLS.log", replace

**********Control Panel*********************************

**specify initial values of parameters in above specification

matrix tinit=J(1,11,15) 

**speficy standard error type****************

global etype robust

**specify initial value for school and field dummies parameters**********

matrix sinit=J(1,50,300)
matrix finit=J(1,14,0) 

**Use default initial values*************************

global initial  "initial(allinit)" /* "" to use default initial values, "initial(allinit)" to use values entered above */ 

********Read in index*******************************

insheet using "index.csv"
keep index`hcode' fixedname
rename index`hcode' index_`hparaname'
save index.dta, replace
clear
insheet using "authdata.csv"
merge fixedname using "index.dta", unique sort
drop _merge
rename tyear T /* each author is at their Tth year after graduation when the data was collected*/

**drop associate professors graduated before 1987
drop if T>25 & pos==2 

**generate school dummies
char nrc[omit] 3
xi , prefix("d") noomit i.nrc 

**generate spline for year of experience
gen T1=min(T,4)-1-3
gen T2=max(min(T,7),4)-4-3
gen T3=max(min(T,10),7)-7-3
gen T6=max(min(T,13),10)-10-3
gen T7=max(min(T,16),13)-13-3
gen T8=max(min(T,20),16)-16-4
gen T9=max(min(T,25),20)-20-3
gen T10=max(min(T,30),25)-25
gen T11=max(min(T,35),30)-30
gen T12=max(min(T,40),35)-35
gen T13=max(T,40)-40

**generate log index
gen ln_index_`hparaname' = ln(index_`hparaname')

gen label = fixedname + string(pos) /* label is to be displayed in graphs for analysis purpose */

*********OLS****************************************

**OLS regression without weights
reg ln_index_`hparaname' dnrc* T1-T13 b-o, robust noconstant 
predict eps,r
gen eps2 = eps*eps

**Predict the squared error conditional on years of experience and school
reg eps2 T1-T13 nrc
predict eps2hat

**weighted OLS regression using the inverse of the root of squared error
gen weight_ols = 1/sqrt(eps2hat)
scatter weight_ols T
graph export `DATE'_`hparaname'_weight_ols.png, replace
reg ln_index_`hparaname' dnrc* T1-T13 b-o [aw = weight_ols], robust noconstant 
predict eps_ols,r
drop eps eps2 eps2hat

**plot the residual wrt year of experience for 1-25 and 26-50 schools
twoway (scatter eps_ols T if nrc<=25 [aweight = weight_ols], mcolor(blue) msize(vsmall) mlabel(label) mlabsize(tiny)) (scatter eps_ols T if nrc>25 [aweight = weight_ols], mcolor(red) msize(vsmall) mlabel(label) mlabsize(tiny)), ytitle(Residual) xtitle(Experience) title(Residual Plot) legend(order(1 "Top 25" 2 "Bottom 25"))
graph export `DATE'_`hparaname'_eps_ols.png,replace
gen eps2_ols = eps_ols^2

gen Tx = _n
replace Tx = . if Tx>62

**calculate the local linear regression smooth of predicted square error using various bandwidth and for full sample, 1-25 schools and 26-50 schools

locpoly eps2_ols T if nrc<=25, noscatter width(10) degree(1) generate(eps2_hat_ols_top25_10) at(Tx)
graph export `DATE'_`hparaname'_eps2_hat_ols_top25_10.png,replace
locpoly eps2_ols T if nrc>25, noscatter width(10) degree(1) generate(eps2_hat_ols_bottom25_10) at(Tx)
graph export `DATE'_`hparaname'_eps2_hat_ols_bottom25_10.png,replace

/*
locpoly eps2_ols T, noscatter width(10) degree(1) generate(eps2_hat_ols_all_10) at(Tx)
graph export `DATE'_`hparaname'_eps2_hat_ols_all_10.png,replace
locpoly eps2_ols T, noscatter width(15) degree(1) generate(eps2_hat_ols_all_15) at(Tx)
graph export `DATE'_`hparaname'_eps2_hat_ols_all_15.png,replace
locpoly eps2_ols T, noscatter width(20) degree(1) generate(eps2_hat_ols_all_20) at(Tx)
graph export `DATE'_`hparaname'_eps2_hat_ols_all_20.png,replace
locpoly eps2_ols T if nrc<=25, noscatter width(15) degree(1) generate(eps2_hat_ols_top25_15) at(Tx)
graph export `DATE'_`hparaname'_eps2_hat_ols_top25_15.png,replace
locpoly eps2_ols T if nrc<=25, noscatter width(20) degree(1) generate(eps2_hat_ols_top25_20) at(Tx)
graph export `DATE'_`hparaname'_eps2_hat_ols_top25_20.png,replace
locpoly eps2_ols T if nrc>25, noscatter width(15) degree(1) generate(eps2_hat_ols_bottom25_15) at(Tx)
graph export `DATE'_`hparaname'_eps2_hat_ols_bottom25_15.png,replace
locpoly eps2_ols T if nrc>25, noscatter width(20) degree(1) generate(eps2_hat_ols_bottom25_20) at(Tx)
graph export `DATE'_`hparaname'_eps2_hat_ols_bottom25_20.png,replace
*/


************************NLLS****************************************************************

**transform the OLS estimates to the corresponding parameters in the NLLS specification and use them as starting values in NLLS.
matrix A = e(b)
matrix B=A[1,1..50]
matrix C=B'
svmat C
replace C1= exp(C1)*100
mkmat C1 if C1!=.
matrix A[1,1] = C1'
matrix A[1,51] = 100*A[1,51..75]
matrix allinit= A

*************************************************************************************************
***Note that the parameters in the NLLS regressions are scaled up by 100 times to increase accuracy. 
*************************************************************************************************


**Check the NLLS specification is essentially the same as the OLS (so it gives the same estimation if the error distribution is assumed the same by the lnlsq(0) option)
nl (index_`hparaname'=(({xb:dnrc*})*0.01)*exp(({xb: T1-T13})*0.01+({xb: b-o})*0.01)) [aw = weight_ols],lnlsq(0) vce($etype) noconstant $initial 
estimates store A

**NLLS regression without weights
nl (index_`hparaname'=(({xb:dnrc*})*0.01)*exp(({xb: T1-T13})*0.01+({xb: b-o})*0.01)), vce($etype) noconstant $initial 
predict eps,r
gen eps2 = eps*eps

**Predict the squared error conditional on years of experience and school
nl (eps2 = exp({xb: T1-T13}*0.01+0.01*{beta}*log(nrc)+{alpha}*0.01))
predict eps2hat

**weighted NLLS regression using the inverse of the root of squared error
gen weight_nlls = 1/sqrt(eps2hat)
scatter weight_nlls T
graph export `DATE'_`hparaname'_weight_nlls.png, replace
nl (index_`hparaname'=(({xb:dnrc*})*0.01)*exp(({xb: T1-T13})*0.01+({xb: b-o})*0.01)) [aw = weight_nlls], vce($etype) noconstant $initial 
predict index_`hparaname'_hat
predict eps_nlls,r
drop eps eps2 eps2hat

**plot the residual wrt year of experience for 1-25 and 26-50 schools
twoway (scatter eps_nlls T if nrc<=25 [aweight = weight_nlls], mcolor(blue) msize(vsmall) mlabel(label) mlabsize(tiny)) (scatter eps_nlls T if nrc>25 [aweight = weight_nlls], mcolor(red) msize(vsmall) mlabel(label) mlabsize(tiny)), ytitle(Residual) xtitle(Experience) title(Residual Plot) legend(order(1 "Top 25" 2 "Bottom 25"))
graph export `DATE'_`hparaname'_eps_nlls.png,replace
gen eps2_nlls = eps_nlls^2


**calculate the local linear regression smooth of predicted square error using various bandwidth and for full sample, 1-25 schools and 26-50 schools
locpoly eps2_nlls T if nrc<=25, noscatter width(10) degree(1) generate(eps2_hat_nlls_top25_10) at(Tx)
graph export `DATE'_`hparaname'_eps2_hat_nlls_top25_10.png,replace
locpoly eps2_nlls T if nrc>25, noscatter width(10) degree(1) generate(eps2_hat_nlls_bottom25_10) at(Tx)
graph export `DATE'_`hparaname'_eps2_hat_nlls_bottom25_10.png,replace

/*
locpoly eps2_nlls T, noscatter width(10) degree(1) generate(eps2_hat_nlls_all_10) at(Tx)
graph export `DATE'_`hparaname'_eps2_hat_nlls_all_10.png,replace
locpoly eps2_nlls T, noscatter width(15) degree(1) generate(eps2_hat_nlls_all_15) at(Tx)
graph export `DATE'_`hparaname'_eps2_hat_nlls_all_15.png,replace
locpoly eps2_nlls T, noscatter width(20) degree(1) generate(eps2_hat_nlls_all_20) at(Tx)
graph export `DATE'_`hparaname'_eps2_hat_nlls_all_20.png,replace
locpoly eps2_nlls T if nrc<=25, noscatter width(15) degree(1) generate(eps2_hat_nlls_top25_15) at(Tx)
graph export `DATE'_`hparaname'_eps2_hat_nlls_top25_15.png,replace
locpoly eps2_nlls T if nrc<=25, noscatter width(20) degree(1) generate(eps2_hat_nlls_top25_20) at(Tx)
graph export `DATE'_`hparaname'_eps2_hat_nlls_top25_20.png,replace
locpoly eps2_nlls T if nrc>25, noscatter width(15) degree(1) generate(eps2_hat_nlls_bottom25_15) at(Tx)
graph export `DATE'_`hparaname'_eps2_hat_nlls_bottom25_15.png,replace
locpoly eps2_nlls T if nrc>25, noscatter width(20) degree(1) generate(eps2_hat_nlls_bottom25_20) at(Tx)
graph export `DATE'_`hparaname'_eps2_hat_nlls_bottom25_20.png,replace
*/

outsheet eps2_hat* using "`DATE'_`hparaname'_eps2_smooth", comma replace

**Calculate the ratio of real index to predicted index

gen ratio_`hparaname'  = index_`hparaname'/index_`hparaname'_hat

**Calculate the year-field-adjusted index. 

matrix A = e(b)
matrix A  = A[1,51..75]
mkmat T1-T13 b-o, mat(X)
matrix B = X*A'
matrix B = B*0.01
svmat B
rename B1 adjust

gen h_tilda_`hparaname'  = index_`hparaname'/exp(adjust)

matrix Af = A[1,12..25]
mkmat b-o,mat(Xf)
matrix Bf = Xf*Af'
matrix Bf = Bf*0.01
svmat Bf
rename Bf1 adjustf
gen h_tilda_f_`hparaname' = index_`hparaname'/exp(adjustf)


**Add cohort information to match the groups of interest in the paper
gen cohort=.
gen phdyear = 2012 - T
replace cohort=1 if phdyear<=1977 & tenure==1
replace cohort=2 if phdyear<=1986 & phdyear>=1978 & tenure==1
replace cohort=3 if phdyear<=1995 & phdyear>=1987 & tenure==1
replace cohort=4 if phdyear<=2004 & phdyear>=1996 & tenure==1
replace cohort=5 if phdyear>=2005 

**Output author level results
outsheet fixedname phdyear cohort nrc pos tenure index_`hparaname' index_`hparaname'_hat  ratio_`hparaname' h_tilda_`hparaname' h_tilda_f_`hparaname' b-m using "`DATE'_adjusted_index_`hparaname'.csv", comma replace

log close /* Regression estimates are stored in the log file*/