% Read in data
IndexImport = importdata('index.csv',',',1);
IndexFull = IndexImport.data;
AuthdataImport = importdata('authdata.csv',',',1);
AuthdataFull = AuthdataImport.data;
AuthdataFull(:,3) = AuthdataFull(:,3) - 23; % Use 1989 as the base year for year adjustment
display('variables in authdata')
display(AuthdataImport.textdata(1,3:end)) % list the definition of columns in author information matrix


% Optionally, we can read in the estimates from a previous version of draft
% and use them as the starting values
load('start.mat')

global data Nsch Nadj 
% Please see llhlogit.m for definition of data, Nsch, Nadj and the format
% of starting values.

% "Young Tenured Sample" (Top 50 NRC School, tenured, phd graduation 1987-2004 )

% Logit model

select = (AuthdataFull(:,2)==1 & AuthdataFull(:,3)<=2 & AuthdataFull(:,3)>=-15);
authdata = AuthdataFull(select,:);
index = IndexFull(select,:);

for i=1:558
i

data = [index(:,i) authdata(:,[1 3:end-2]) authdata(:,3).^2];
Nsch = 50;
Nadj = 16; % The linear adjustment terms are (in order) : year (1989 as base), fields (behavioral - other, macro as base), year^2
%We have tried different starting values, the following is an example
%start = [1 1.2/std(log(data(:,1))) mean(log(data(:,1)))+1+std(log(data(:,1))):-2*std(log(data(:,1)))/Nsch:mean(log(data(:,1)))+1-std(log(data(:,1)))+1e-3 -0.003	-0.116644008	0.089679378	0.244108613	-0.004642684	0.3	0.3	0.112285962	-0.03172188	-0.076223964	0.012934516	0.116027283	0.058412007	0.3	-0.3	0.002];
start = start_Default(i,:);
%In fmincon, we specify proper bounds for the parameters to improve speed
%and accuracy
[output, theFunVal,theFlag,msg]= fmincon(@(x) -llhlogit2(x),start,[],[],[],[],[ 0.5 0 -10 * ones(1,Nsch) -1 -30*ones(1,14) -1e-1 ],[2 30 (5 + max(data(:,1))) * ones(1,Nsch) 1 30*ones(1,14) 1e-1],[],optimset('algorithm','interior-point','MaxFunEvals',1e10,'MaxIter',1e5,'SubproblemAlgorithm','cg','TolX',1e-12,'TolFun',1e-10));
output=[theFunVal msg.firstorderopt double(theFlag) output];
ResultDefault(i,:)=output
end

%The content of Outsheet matrices are copied to the spreadsheets showing
%the results
OutsheetDefault = [mean(index)' -ResultDefault(:,1) ResultDefault(:,4:end)];

% Ordered Probit model
for i = 1:553
    i
    data = [index(:,i) authdata(:,[1 3:end-2]) authdata(:,3).^2];
    Nsch = 50;
    Nadj = 16;
    % The following is an example of the starting value we have tried.
    % start = [[ 3 -0.003 (rand(1,Nadj-2)-0.5) 0.001 (5/Nsch)*ones(1,Nsch-1)]]
    start = start_Probit(i-1,:);
    [output, theFunVal,theFlag,msg] = fmincon(@(x) -llhprobit(x),start,[0 ones(1,Nsch-1) zeros(1,Nadj)],20,[],[],[ 0,-20,zeros(1,Nsch-2),-30*ones(1,Nadj)],[20*ones(1,Nsch),30*ones(1,Nadj)],[],optimset('algorithm','interior-point','MaxFunEvals',1e10,'MaxIter',1e10))
    output=[theFunVal msg.firstorderopt double(theFlag) output];
    ResultProbit(i,:) = output;
end

schooldum = cumsum(ResultProbit(:,5:53),2);
schooldum = schooldum(:,end:-1:1);
OutsheetProbit = [mean(index(:,1:553))' -ResultProbit(:,1) ResultProbit(:,4) schooldum ResultProbit(:,end-Nadj+1:end)];

% Top 25 school Young Tenured Sample (Top 25 NRC School, tenured, phd graduation
% 1987-2004 )  Logit model only.
select = (AuthdataFull(:,2)==1 & AuthdataFull(:,3)<=2 & AuthdataFull(:,3)>=-15 & AuthdataFull(:,1)<=25);
authdata = AuthdataFull(select,:);
index = IndexFull(select,:);

for i=1:558
i
data = [index(:,i) authdata(:,[1 3:end-2]) authdata(:,3).^2];
Nsch = 25;
Nadj = 16;
start = start_Top25(i,:);
%start = [1 1.2/std(log(data(:,1))) mean(log(data(:,1)))+1+std(log(data(:,1))):-2*std(log(data(:,1)))/Nsch:mean(log(data(:,1)))+1-std(log(data(:,1)))+1e-3 -0.003	-0.116644008	0.089679378	0.244108613	-0.004642684	0.3	0.3	0.112285962	-0.03172188	-0.076223964	0.012934516	0.116027283	0.058412007	0.3	-0.3	0.002];
[output, theFunVal,theFlag,msg]= fmincon(@(x) -llhlogit2(x),start,[],[],[],[],[ 0.5 0 -10 * ones(1,Nsch) -1 -30*ones(1,14) -1e-1 ],[2 30 (5 + max(data(:,1))) * ones(1,Nsch) 1 30*ones(1,14) 1e-1],[],optimset('algorithm','interior-point','MaxFunEvals',1e10,'MaxIter',1e5,'SubproblemAlgorithm','cg','TolX',1e-12,'TolFun',1e-10));
output=[theFunVal msg.firstorderopt double(theFlag) output];
ResultTop25(i,:)=output
end

OutsheetTop25 = [mean(index)' -ResultTop25(:,1) ResultTop25(:,4:end)];

% 26th - 50th school Young Tenured Sample (26th - 50th NRC School, tenured, phd graduation
% 1987-2004 )  Logit model only.

select = (AuthdataFull(:,2)==1 & AuthdataFull(:,3)<=2 & AuthdataFull(:,3)>=-15 & AuthdataFull(:,1)>25);
authdata = AuthdataFull(select,:);
index = IndexFull(select,:);
authdata(:,1) = authdata(:,1) - 25;



for i=1:558
i
data = [index(:,i) authdata(:,[1 3:end-2]) authdata(:,3).^2];
Nsch = 25;
Nadj = 16;
start = start_Bottom25(i,:);
%start = [1 1.2/std(log(data(:,1))) mean(log(data(:,1)))+1+std(log(data(:,1))):-2*std(log(data(:,1)))/Nsch:mean(log(data(:,1)))+1-std(log(data(:,1)))+1e-3 -0.003	-0.116644008	0.089679378	0.244108613	-0.004642684	0.3	0.3	0.112285962	-0.03172188	-0.076223964	0.012934516	0.116027283	0.058412007	0.3	-0.3	0.002];
start = [1.019314054	1	mean(log(data(:,1)))+1+std(log(data(:,1))):-2*std(log(data(:,1)))/Nsch:mean(log(data(:,1)))+1-std(log(data(:,1)))+1e-3	-0.1	0.1*ones(1,14)	-0.0016748243]
[output, theFunVal,theFlag,msg]= fmincon(@(x) -llhlogit2(x),start,[],[],[],[],[ 0.5 0 -10 * ones(1,Nsch) -1 -30*ones(1,14) -1e-1 ],[2 30 (5 + max(data(:,1))) * ones(1,Nsch) 1 30*ones(1,14) 1e-1],[],optimset('algorithm','interior-point','MaxFunEvals',1e10,'MaxIter',1e5,'SubproblemAlgorithm','cg','TolX',1e-12,'TolFun',1e-10));
output=[theFunVal msg.firstorderopt double(theFlag) output];
ResultBottom25(i,:)=output
end

OutsheetBottom25 = [mean(index)' -ResultBottom25(:,1) ResultBottom25(:,4:end)];

% Top 50 school Elder Tenured Sample (Top 50 NRC School, tenured, phd graduation
% 1978 - 1986 )  Logit model only.

select = (AuthdataFull(:,2)==1 & AuthdataFull(:,3)<=11 & AuthdataFull(:,3)>=3);
authdata = AuthdataFull(select,:);
index = IndexFull(select,:);
authdata(authdata(:,1)>40,1) = authdata(authdata(:,1)>40,1)-1;



for i=1:558
i
data = [index(:,i) authdata(:,[1 3:end-2]) authdata(:,3).^2];
Nsch = 49;
Nadj = 16;
%start = start_Pre1986(i,:);
start = [1 1.2/std(log(data(:,1))) mean(log(data(:,1)))+1+std(log(data(:,1))):-2*std(log(data(:,1)))/Nsch:mean(log(data(:,1)))+1-std(log(data(:,1)))+1e-3 -0.003	-0.116644008	0.089679378	0.244108613	-0.004642684	0.3	0.3	0.112285962	-0.03172188	-0.076223964	0.012934516	0.116027283	0.058412007	0.3	-0.3	0.002];
[output, theFunVal,theFlag,msg]= fmincon(@(x) -llhlogit2(x),start,[],[],[],[],[ 0.5 0 -10 * ones(1,Nsch) -1 -30*ones(1,14) -1e-1 ],[2 30 (5 + max(data(:,1))) * ones(1,Nsch) 1 30*ones(1,14) 1e-1],[],optimset('algorithm','interior-point','MaxFunEvals',1e10,'MaxIter',1e5,'SubproblemAlgorithm','cg','TolX',1e-12,'TolFun',1e-10));
output=[theFunVal msg.firstorderopt double(theFlag) output];
ResultPre1986(i,:)=output
%save('Nov02Pre1986')
end

OutsheetPre1986 = [mean(index)' -ResultPre1986(:,1) ResultPre1986(:,4:end)];

% Top 50 school Young (first half) Tenured Sample (Top 50 NRC School, tenured, phd graduation
% 1987 - 1995)  Logit model only.

select = (AuthdataFull(:,2)==1 & AuthdataFull(:,3)<=2 & AuthdataFull(:,3)>=-6);
authdata = AuthdataFull(select,:);
index = IndexFull(select,:);
authdata(authdata(:,1)>30,1) = authdata(authdata(:,1)>30,1)-1;

for i=1:558
i
data = [index(:,i) authdata(:,[1 3:end-2]) authdata(:,3).^2];
Nsch = 49;
Nadj = 16;
%start = start_Pre1995(i,:);
start = [1 1.2/std(log(data(:,1))) mean(log(data(:,1)))+1+std(log(data(:,1))):-2*std(log(data(:,1)))/Nsch:mean(log(data(:,1)))+1-std(log(data(:,1)))+1e-3 -0.003	-0.116644008	0.089679378	0.244108613	-0.004642684	0.3	0.3	0.112285962	-0.03172188	-0.076223964	0.012934516	0.116027283	0.058412007	0.3	-0.3	0.002];
[output, theFunVal,theFlag,msg]= fmincon(@(x) -llhlogit2(x),start,[],[],[],[],[ 0.5 0 -10 * ones(1,Nsch) -1 -30*ones(1,14) -1e-1 ],[2 30 (5 + max(data(:,1))) * ones(1,Nsch) 1 30*ones(1,14) 1e-1],[],optimset('algorithm','interior-point','MaxFunEvals',1e10,'MaxIter',1e5,'SubproblemAlgorithm','cg','TolX',1e-12,'TolFun',1e-10));
output=[theFunVal msg.firstorderopt double(theFlag) output];
ResultPre1995(i,:)=output
save('Nov02Pre1995')
end

OutsheetPre1995 = [mean(index)' -ResultPre1995(:,1) ResultPre1995(:,4:end)];

% Top 50 school Young (second half) Tenured Sample (Top 50 NRC School, tenured, phd graduation
% 1996 - 2004)  Logit model only.

select = (AuthdataFull(:,2)==1 & AuthdataFull(:,3)<=-7 & AuthdataFull(:,3)>=-15);
authdata = AuthdataFull(select,:);
index = IndexFull(select,:);
authdata(authdata(:,1)>26,1) = authdata(authdata(:,1)>26,1)-1;
authdata(authdata(:,1)>40,1) = authdata(authdata(:,1)>40,1)-1;
authdata(authdata(:,1)>42,1) = authdata(authdata(:,1)>42,1)-1;

for i=1:558
i
data = [index(:,i) authdata(:,[1 3:end-2]) authdata(:,3).^2];
Nsch = 47;
Nadj = 16;
start = start_Post1996(i,:);
%start = [1 1.2/std(log(data(:,1))) mean(log(data(:,1)))+1+std(log(data(:,1))):-2*std(log(data(:,1)))/Nsch:mean(log(data(:,1)))+1-std(log(data(:,1)))+1e-3 -0.003	-0.116644008	0.089679378	0.244108613	-0.004642684	0.3	0.3	0.112285962	-0.03172188	-0.076223964	0.012934516	0.116027283	0.058412007	0.3	-0.3	0.002];
[output, theFunVal,theFlag,msg]= fmincon(@(x) -llhlogit2(x),start,[],[],[],[],[ 0.5 0 -10 * ones(1,Nsch) -1 -100*ones(1,14) -1e-1 ],[2 30 (5 + max(data(:,1))) * ones(1,Nsch) 1 100*ones(1,14) 1e-1],[],optimset('algorithm','interior-point','MaxFunEvals',1e10,'MaxIter',1e5,'SubproblemAlgorithm','cg','TolX',1e-12,'TolFun',1e-10));
output=[theFunVal msg.firstorderopt double(theFlag) output];
ResultPost1996(i,:)=output
end

OutsheetPost1996 = [mean(index)' -ResultPost1996(:,1) ResultPost1996(:,4:end)];

% Top 50 school Junior Untenured Sample (Top 50 NRC School, untenured, phd graduation
% after 2005)  Logit model only.

select = (AuthdataFull(:,2) == 0 & AuthdataFull(:,3) <= -16);
authdata = AuthdataFull(select,:);
index = IndexFull(select,:);
authdata(authdata(:,1)>41,1) = authdata(authdata(:,1)>41,1)-1;
authdata(:,3) = authdata(:,3) + 16;

for i=1:558
i
data = [index(:,i) authdata(:,[1 3:end-2]) authdata(:,3).^2];
Nsch = 49;
Nadj = 16;
start = start_Post2005(i,:);
%start = [1 1.2/std(log(data(:,1))) mean(log(data(:,1)))+1+std(log(data(:,1))):-2*std(log(data(:,1)))/Nsch:mean(log(data(:,1)))+1-std(log(data(:,1)))+1e-3 -0.003	-0.116644008	0.089679378	0.244108613	-0.004642684	0.3	0.3	0.112285962	-0.03172188	-0.076223964	0.012934516	0.116027283	0.058412007	0.3	-0.3	0.002];
[output, theFunVal,theFlag,msg]= fmincon(@(x) -llhlogit2(x),start,[],[],[],[],[ 0.5 0 -10 * ones(1,Nsch) -1 -30*ones(1,14) -1e-1 ],[2 30 (5 + max(data(:,1))) * ones(1,Nsch) 1 30*ones(1,14) 1e-1],[],optimset('algorithm','interior-point','MaxFunEvals',1e10,'MaxIter',1e5,'SubproblemAlgorithm','cg','TolX',1e-12,'TolFun',1e-10));
output=[theFunVal msg.firstorderopt double(theFlag) output];
ResultPost2005(i,:)=output
end

OutsheetPost2005 = [mean(index)' -ResultPost2005(:,1) ResultPost2005(:,4:end)];





